==> am_mod_blg_0_1.tar.gz: am_mod_blg_0_1/components/blg/template/barnraiser_01/inc/menu_blog.inc.php <==
<?php
// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<span class="txt_highlight"><?php echo $lang['menu_label_view'];?>:</span>
&nbsp;

<?php
$link_css = "";
if ($page_name_short == "overview") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=blg_overview"<?php echo $link_css;?>><?php echo $lang['menu_overview'];?></a>
&nbsp;

<?php
$link_css = "";
if ($page_name_short == "meta") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=blg_meta"<?php echo $link_css;?>><?php echo $lang['menu_meta'];?></a>
&nbsp;

<?php
if (isset($blog)) {
?>
	&#124;
	&nbsp;
	<span class="txt_highlight"><?php echo $lang['menu_label_blog'];?>:</span>

	&nbsp;
	<?php
	$link_css = "";
	if ($page_name_short == "blg_item") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=blg_item&blog_id=<?php echo $blog['blog_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_home_page'];?></a>
	&nbsp;

	<?php
	$link_css = "";
	if ($page_name_short == "participation") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=blg_participation&amp;blog_id=<?php echo $blog['blog_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_participation'];?></a>
	&nbsp;
	
	<?php
	if (isset($_SESSION['user_id']) && $blog['user_id'] == $_SESSION['user_id']) {
	$link_css = "";
	if ($page_name_short == "blog_edit") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=blg_manage&amp;blog_id=<?php echo $blog['blog_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_manage'];?></a>
	&nbsp;
	<?php }?>

	<?php
	if (isset($participation) && $participation['participation_permission'] & $blog_config['resource']['user']['allow_invite']) {
	$link_css = "";
	if ($page_name_short == "invite") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=blg_invite&amp;blog_id=<?php echo $blog['blog_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_invite'];?></a>
	&nbsp;
	<?php }?>
	
	
	<?php
	$link_css = "";
	if ($page_name_short == "file") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_fil_view&amp;module_id=<?php echo $core_config['module_id']['blog'];?>&amp;item_id=<?php echo $blog['blog_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_files'];?></a>
	&nbsp;
<?php }?>

<?php
if (!isset($sub_section) && !isset($blog)) {
?>
	<?php
	if ($_SESSION['user_mod_permission'] & $resource['module']['blg']['create']) {
	?>

	&#124;
	&nbsp;
	<span class="txt_highlight"><?php echo $lang['menu_label_do'];?>:</span>
	&nbsp;

	<?php
	$link_css = "";
	if ($page_name_short == "blog_edit") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=blg_blog_edit"<?php echo $link_css;?>><?php echo $lang['menu_create'];?></a>
	&nbsp;
	<?php }?>
<?php }?>

<?php
if (isset($blog) && $_SESSION['user_mod_permission'] & $blog_config['resource']['user']['allow_create_entry']) {
?>
	<?php
	$link_css = "";
	if ($page_name_short == "blg_entry_edit") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=blg_entry_edit&amp;blog_id=<?php echo $blog['blog_id'];?>"><?php echo $lang['menu_create_entry'];?></a>
	&nbsp;
<?php }?>

<?php
$link_css = "";
if ($page_name_short == "list") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=blg_list"<?php echo $link_css;?>><?php echo $lang['menu_search'];?></a>
<br />

==> am_mod_blg_0_3.tar.gz: am_mod_blg_0_3/components/blg/template/barnraiser_01/inc/menu_blog.inc.php <==
<?php
// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<span class="txt_highlight"><?php echo $lang['menu_label_view'];?>:</span>
&nbsp;

<?php
$link_css = "";
if ($page_name_short == "overview") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=blg_overview"<?php echo $link_css;?>><?php echo $lang['menu_overview'];?></a>
&nbsp;

<?php
$link_css = "";
if ($page_name_short == "meta") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=blg_meta"<?php echo $link_css;?>><?php echo $lang['menu_meta'];?></a>
&nbsp;

<?php
if (isset($blog)) {
?>
	&#124;
	&nbsp;
	<span class="txt_highlight"><?php echo $lang['menu_label_blog'];?>:</span>

	&nbsp;
	<?php
	$link_css = "";
	if ($page_name_short == "blg_item") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=blg_item&amp;blog_id=<?php echo $blog['blog_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_home_page'];?></a>
	&nbsp;

	<?php
	if (isset($_SESSION['md5'])) {
	if (($blog['blog_type'] == $blog_config['type']['membership_type']) || ($blog['blog_type'] != $blog_config['type']['invitation'])) {
	$link_css = "";
	if ($page_name_short == "participation") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_participation&amp;module_id=<?php echo $core_config['module_id']['blog'];?>&amp;item_id=<?php echo $blog['blog_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_participation'];?></a>
	&nbsp;
	<?php }}?>
	
	<?php
	if (isset($_SESSION['user_id']) && $blog['user_id'] == $_SESSION['user_id']) {
	$link_css = "";
	if ($page_name_short == "blog_edit") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=blg_manage&amp;blog_id=<?php echo $blog['blog_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_manage'];?></a>
	&nbsp;
	<?php }?>

	<?php
	if (isset($participation) && $participation['participation_permission'] & $blog_config['resource']['user']['allow_invite']) {
	$link_css = "";
	if ($page_name_short == "invite") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_invite&amp;module_id=<?php echo $core_config['module_id']['blog'];?>&amp;item_id=<?php echo $blog['blog_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_invite'];?></a>
	&nbsp;
	<?php }?>
	
	
	<?php
	$link_css = "";
	if ($page_name_short == "file") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_fil_view&amp;module_id=<?php echo $core_config['module_id']['blog'];?>&amp;item_id=<?php echo $blog['blog_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_files'];?></a>
	&nbsp;
<?php }?>

<?php
if (!isset($sub_section) && !isset($blog)) {
?>
	<?php
	if ($_SESSION['user_mod_permission'] & $resource['module']['blg']['create']) {
	?>

	&#124;
	&nbsp;
	<span class="txt_highlight"><?php echo $lang['menu_label_do'];?>:</span>
	&nbsp;

	<?php
	$link_css = "";
	if ($page_name_short == "blog_edit") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=blg_blog_edit"<?php echo $link_css;?>><?php echo $lang['menu_create'];?></a>
	&nbsp;
	<?php }?>
<?php }?>

<?php
if (isset($blog) && $_SESSION['user_mod_permission'] & $blog_config['resource']['user']['allow_create_entry']) {
?>
	<?php
	$link_css = "";
	if ($page_name_short == "blg_entry_edit") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=blg_entry_edit&amp;blog_id=<?php echo $blog['blog_id'];?>"><?php echo $lang['menu_create_entry'];?></a>
	&nbsp;
<?php }?>

<?php
$link_css = "";
if ($page_name_short == "list") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=blg_list"<?php echo $link_css;?>><?php echo $lang['menu_search'];?></a>
<br />
